@@ -22,8 +22,8 @@ Gst_Nei <- function(x){
   n <- length(unique(pop(x)))
   Gst.per.locus <- function(g) { 
     hets <- HsHt(g,n) #A private function form mmod
-    Ht_est <- hets["Ht_est"]
-    Hs_est <- hets["Hs_est"]
+    Ht_est <- hets[1]
+    Hs_est <- hets[2]
     G_est <- (Ht_est-Hs_est)/Ht_est
     return(c(Hs_est, Ht_est, G_est))
   }
