@@ -21,7 +21,7 @@ pairwise_Gst_Hedrick<- function(x, linearized=FALSE) {
   pops <- seppop(x)
   n.pops <- length(pops)
   #all combinations 
-  allP <- combn(1:n.pops, 2)
+  allP <- utils::combn(1:n.pops, 2)
   # calculate the statistic
   pair <- function(index.a,index.b){
     a <- pops[[index.a]]
