@@ -10,8 +10,22 @@
 #' 
 #'
 #' @param bs list of genind objects
-#' @param statistic differentiation statistic to apply.
+#' @param statistic differentiation statistic to apply (the function itself, 
+#' as with apply family functions)
 #' @family resample
+#' @return per.locus:  matrix of statistics calculated for each locus and each 
+#' bootstrap replication
+#' @return global.het: vector of global estimates calculated from overall 
+#' heterozygosity 
+#' @return global.het: vector of global estimates calculated from harmonic
+#' mean of statistic (only applied to D_Jost)
+#' @return summary.loci: matrix containing mean, .025 and 0.975 percentile and
+#' varaince of statisic for each locus
+#' @return summary.global_het: mean, .025 and 0.975 percentile and variance for
+#' global estimate variance of statistic for each locus based on heterozygosity
+#' @return summary.global_harm: mean, .025 and 0.975 percentile and variance for
+#' global estimate variance of statistic for each locus based on harmonic mean
+# (only applies to D_Jost)
 #' @export
 #' @examples
 #'\dontrun{  
@@ -21,7 +35,7 @@
 #'}
 
 
-summarise_bootsrap <- function(bs, statistic){
+summarise_bootstrap <- function(bs, statistic){
   nreps <- length(bs)
   stats <- sapply(bs, statistic)
   loc_stats <- do.call(rbind, stats["per.locus",])
